.. Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0
.. For details: https://github.com/coveragepy/coveragepy/blob/main/NOTICE.txt

.. _api_coveragedata:

The CoverageData class
----------------------

.. versionadded:: 4.0

.. autoclass:: coverage.CoverageData
    :members:
    :special-members: __init__
